/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include <stdio.h>
#include <stdlib.h>

void fatal(token,msg) /* print token, message, then croak */
char *token, *msg;
{
	fprintf(stderr,"fatal error ");

	if (token != NULL && *token != '\0') fprintf(stderr,"<%s> ", token);

	if (msg != NULL && *msg != '\0') fprintf(stderr,"%s", msg);

	fprintf(stderr,"\n");

	abort();
}
